﻿using Connected.Services.Modal;
using Microsoft.AspNetCore.Components;

namespace Connected.Components;
public partial class ModalDialog: IDisposable
{
	[Inject] ModalDialogService? ModalService { get; set; }

	protected bool IsVisible { get; set; }
	protected string? Title { get; set; }
	protected RenderFragment? Content { get; set; }

	protected EventCallback OnConfirm { get; set; }

	protected override void OnInitialized()
	{
		ModalService.OnShow += ShowModal;
		ModalService.OnClose += CloseModal;
	}

	public void ShowModal(string title, RenderFragment content, EventCallback o, string CancelButtonText = "Cancel", string OKButtonText = "OK")
	{
		Title = title;
		Content = content;
		IsVisible = true;

		this.OKButtonText = OKButtonText;
		this.CancelButtonText = CancelButtonText;

		OnConfirm = o;

		StateHasChanged();
	}

	public void ShowModal(string title, MarkupString content, EventCallback o, string CancelButtonText = "Cancel", string OKButtonText = "OK")
	{
		Title = title;
		Content = new RenderFragment(x => x.AddContent(1, content));
		IsVisible = true;

		this.OKButtonText = OKButtonText;
		this.CancelButtonText = CancelButtonText;

		OnConfirm = o;

		StateHasChanged();
	}

	public void CloseModal(bool OkClicked = false)
	{
		IsVisible = false;
		Title = "";
		Content = null;
		if (OkClicked)
			OnConfirm.InvokeAsync();
		StateHasChanged();
	}

	public void Dispose()
	{
		if (ModalService is not null)
		{
			ModalService.OnShow -= ShowModal;
			ModalService.OnClose -= CloseModal;
		}
	}

	[Parameter]
	public EventCallback OnOkClick { get; set; }

	[Parameter]
	public string OKButtonText { get; set; } ="OK";

	[Parameter]
	public string CancelButtonText { get; set; } = "Cancel";

}